==> CGAL-5.2.2-doc_html.tar.xz: doc_html/Kernel_23/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - 2D and 3D Linear Geometry Kernel", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#kernel_intro", [
        [ "Robustness", "index.html#Kernel_23Robustness", null ]
      ] ],
      [ "Kernel Representations", "index.html#kernel_rep", [
        [ "Genericity Through Parameterization", "index.html#Kernel_23GenericityThroughParameterization", null ],
        [ "Cartesian Kernels", "index.html#Kernel_23CartesianKernels", null ],
        [ "Homogeneous Kernels", "index.html#Kernel_23HomogeneousKernels", null ],
        [ "Naming Conventions", "index.html#Kernel_23NamingConventions", null ],
        [ "Kernel as a Traits Class", "index.html#Kernel_23KernelasaTraitsClass", null ],
        [ "Choosing a Kernel and Predefined Kernels", "index.html#Kernel_23ChoosingaKernelandPredefinedKernels", [
          [ "Predefined Kernels", "index.html#Kernel_23PredefinedKernels", null ]
        ] ]
      ] ],
      [ "Kernel Geometry", "index.html#Kernel_23Kernel", [
        [ "Points and Vectors", "index.html#Kernel_23PointsandVectors", null ],
        [ "Kernel Objects", "index.html#Kernel_23KernelObjects", null ],
        [ "Orientation and Relative Position", "index.html#Kernel_23OrientationandRelativePosition", null ]
      ] ],
      [ "Predicates and Constructions", "index.html#Kernel_23Predicates", [
        [ "Predicates", "index.html#Kernel_23Predicates_1", null ],
        [ "Constructions", "index.html#Kernel_23Constructions", null ],
        [ "Intersections and Variant Return Types", "index.html#Kernel_23VariantReturnValues", null ],
        [ "Constructive Predicates", "index.html#Kernel_23ConstructivePredicates", null ]
      ] ],
      [ "Extensible Kernel", "index.html#sectionextensiblekernel", [
        [ "Introduction", "index.html#Kernel_23Introduction", null ],
        [ "An Extensive Example", "index.html#Kernel_23AnExtensiveExample", null ],
        [ "Limitations", "index.html#Kernel_23Limitations", null ]
      ] ],
      [ "Projection Traits Classes", "index.html#sectionprojectiontraits", null ],
      [ "Design and Implementation History", "index.html#Kernel_23Design", [
        [ "Acknowledgment", "index.html#Kernel_23Acknowledgment", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Filtered_kernel_2Filtered_predicate_8cpp-example.html",
"classCGAL_1_1Line__2.html#a34bcf520b7c50ec25e116e4c9abea2fb",
"classCGAL_1_1Sphere__3.html#ad34fc88c16adbc448cb9d5d3ebef0fe8",
"classKernel.html#a455b024b7dbc76be321ba756308f8ff7",
"classKernel_1_1AreParallel__3.html#a36548de4a1d83772b01829b491d06dbb",
"classKernel_1_1ComputeXmin__3.html#ab7aea420ecebdc0c1bff6ab2637e8855",
"classKernel_1_1ConstructRadicalLine__2.html#aeca48303c1e44142c2e003b2b3b02fbc",
"classKernel_1_1LessSignedDistanceToPlane__3.html#ab68efd87026402d57bb3fef1609bd191",
"group__compare__y__spherical__grp.html#gaa91ade50fb9ca7e99a7b4a23b92b497e",
"refines.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Kernel_23/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - 2D and 3D Linear Geometry Kernel", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#kernel_intro", [
        [ "Robustness", "index.html#Kernel_23Robustness", null ]
      ] ],
      [ "Kernel Representations", "index.html#kernel_rep", [
        [ "Genericity Through Parameterization", "index.html#Kernel_23GenericityThroughParameterization", null ],
        [ "Cartesian Kernels", "index.html#Kernel_23CartesianKernels", null ],
        [ "Homogeneous Kernels", "index.html#Kernel_23HomogeneousKernels", null ],
        [ "Naming Conventions", "index.html#Kernel_23NamingConventions", null ],
        [ "Kernel as a Traits Class", "index.html#Kernel_23KernelasaTraitsClass", null ],
        [ "Choosing a Kernel and Predefined Kernels", "index.html#Kernel_23ChoosingaKernelandPredefinedKernels", [
          [ "Predefined Kernels", "index.html#Kernel_23PredefinedKernels", null ]
        ] ]
      ] ],
      [ "Kernel Geometry", "index.html#Kernel_23Kernel", [
        [ "Points and Vectors", "index.html#Kernel_23PointsandVectors", null ],
        [ "Kernel Objects", "index.html#Kernel_23KernelObjects", null ],
        [ "Orientation and Relative Position", "index.html#Kernel_23OrientationandRelativePosition", null ]
      ] ],
      [ "Predicates and Constructions", "index.html#Kernel_23Predicates", [
        [ "Predicates", "index.html#Kernel_23Predicates_1", null ],
        [ "Constructions", "index.html#Kernel_23Constructions", null ],
        [ "Intersections and Variant Return Types", "index.html#Kernel_23VariantReturnValues", null ],
        [ "Constructive Predicates", "index.html#Kernel_23ConstructivePredicates", null ]
      ] ],
      [ "Extensible Kernel", "index.html#sectionextensiblekernel", [
        [ "Introduction", "index.html#Kernel_23Introduction", null ],
        [ "An Extensive Example", "index.html#Kernel_23AnExtensiveExample", null ],
        [ "Limitations", "index.html#Kernel_23Limitations", null ]
      ] ],
      [ "Projection Traits Classes", "index.html#sectionprojectiontraits", null ],
      [ "Design and Implementation History", "index.html#Kernel_23Design", [
        [ "Acknowledgment", "index.html#Kernel_23Acknowledgment", null ]
      ] ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Filtered_kernel_2Filtered_predicate_8cpp-example.html",
"classCGAL_1_1Iso__rectangle__2.html#ae5fa468ae40345d66893dd56cf80ee75",
"classCGAL_1_1Sphere__3.html#a74ef3da6618b4c6d93ea59bff3db6291",
"classKernel.html#a39fb0222695ae5e7e32f4e570ea28225",
"classKernel_1_1AreOrderedAlongLine__2.html#ab5f06b9d09599dc79576d069ecd4cf2c",
"classKernel_1_1ComputeX__2.html#ab790f8d36ba684507bfbb815b1d6fa83",
"classKernel_1_1ConstructProjectedPoint__2.html",
"classKernel_1_1IsoRectangle__2.html",
"group__compare__xyz__spherical__grp.html",
"index.html#Kernel_23KernelObjects"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
